@@ -1,3 +1,4 @@
+import asyncio
 import logging
 import plistlib
 import ssl
@@ -50,10 +51,21 @@ def parse_plist(payload):
         raise PyMobileDevice3Exception(f'recv_plist invalid data: {payload[:100].hex()}')
 
 
+def create_context(keyfile, certfile):
+    context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
+    context.set_ciphers('AES256-SHA')
+    context.check_hostname = False
+    context.verify_mode = ssl.CERT_NONE
+    context.load_cert_chain(certfile, keyfile)
+    return context
+
+
 class ServiceConnection(object):
     def __init__(self, socket):
         self.logger = logging.getLogger(__name__)
         self.socket = socket
+        self._reader = None  # type: asyncio.StreamReader
+        self._writer = None  # type: asyncio.StreamWriter
 
     @staticmethod
     def create(udid, port):
@@ -73,6 +85,14 @@ class ServiceConnection(object):
     def close(self):
         self.socket.close()
 
+    async def aio_close(self):
+        if self._writer is None:
+            return
+        self._writer.close()
+        await self._writer.wait_closed()
+        self._writer = None
+        self._reader = None
+
     def recv(self, length=4096):
         """ socket.recv() normal behavior. attempt to receive a single chunk """
         return self.socket.recv(length)
@@ -109,6 +129,12 @@ class ServiceConnection(object):
                 # Allow ssl to do stuff
                 time.sleep(0)
 
+    async def aio_recv_prefixed(self, endianity='>'):
+        """ receive a data block prefixed with a u32 length field """
+        size = await self._reader.readexactly(4)
+        size = struct.unpack(endianity + 'L', size)[0]
+        return await self._reader.readexactly(size)
+
     def send_prefixed(self, data):
         """ send a data block prefixed with a u32 length field """
         if isinstance(data, str):
@@ -120,16 +146,25 @@ class ServiceConnection(object):
     def recv_plist(self, endianity='>'):
         return parse_plist(self.recv_prefixed(endianity=endianity))
 
+    async def aio_recv_plist(self, endianity='>'):
+        return parse_plist(await self.aio_recv_prefixed(endianity))
+
     def send_plist(self, d, endianity='>', fmt=plistlib.FMT_XML):
         return self.sendall(build_plist(d, endianity, fmt))
 
+    async def aio_send_plist(self, d, endianity='>', fmt=plistlib.FMT_XML):
+        self._writer.write(build_plist(d, endianity, fmt))
+        await self._writer.drain()
+
     def ssl_start(self, keyfile, certfile):
-        context = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
-        context.set_ciphers('AES256-SHA')
-        context.check_hostname = False
-        context.verify_mode = ssl.CERT_NONE
-        context.load_cert_chain(certfile, keyfile)
-        self.socket = context.wrap_socket(self.socket)
+        self.socket = create_context(keyfile, certfile).wrap_socket(self.socket)
+
+    async def aio_ssl_start(self, keyfile, certfile):
+        self._reader, self._writer = await asyncio.open_connection(
+            sock=self.socket,
+            ssl=create_context(keyfile, certfile),
+            server_hostname=''
+        )
 
     def shell(self):
         IPython.embed(
